magneticalc.Norm_Types

# ``magneticalc`.`Norm_Types``

module documentation

Norm_Types module.

Function | `norm_name_to_type` | Converts a norm name to a norm type.
Function | `norm_type_safe` | A valid norm type is passed through, but an invalid norm type converts to the default type.
Function | `norm_type_to_name` | Converts a norm type to a norm name.
Constant | `NORM_TYPE_ANGLE_XY` | Norm type: Angle XZ.
Constant | `NORM_TYPE_ANGLE_XZ` | Norm type: Angle YZ.
Constant | `NORM_TYPE_ANGLE_YZ` | Norm type: Divergence.
Constant | `NORM_TYPE_DIVERGENCE` | Map of norm types to names.
Constant | `NORM_TYPE_RADIUS` | Norm type: Radius X.
Constant | `NORM_TYPE_RADIUS_X` | Norm type: Radius Y.
Constant | `NORM_TYPE_RADIUS_XY` | Norm type: Radius XZ.
Constant | `NORM_TYPE_RADIUS_XZ` | Norm type: Radius YZ.
Constant | `NORM_TYPE_RADIUS_Y` | Norm type: Radius Z.
Constant | `NORM_TYPE_RADIUS_YZ` | Norm type: Angle XY.
Constant | `NORM_TYPE_RADIUS_Z` | Norm type: Radius XY.
Constant | `NORM_TYPE_X` | Norm type: Y.
Constant | `NORM_TYPE_Y` | Norm type: Z.
Constant | `NORM_TYPE_Z` | Norm type: Radius.
Variable | `Norm_Types_Names_Map` | Default norm type.

def norm_name_to_type(norm_name: `str`) -> `int`:

Converts a norm name to a norm type.

Parameters
norm_name: `str` | Norm name @return Norm type

Returns
`int` | Undocumented

def norm_type_safe(norm_type: `int`) -> `int`:

A valid norm type is passed through, but an invalid norm type converts to the default type.

Parameters
norm_type: `int` | Norm type

Returns
`int` | Safe norm type

def norm_type_to_name(norm_type: `int`) -> `str`:

Converts a norm type to a norm name.

Parameters
norm_type: `int` | Norm type

Returns
`str` | Norm name

NORM_TYPE_ANGLE_XY: `int` =

Norm type: Angle XZ.

Value
    10

NORM_TYPE_ANGLE_XZ: `int` =

Norm type: Angle YZ.

Value
    11

NORM_TYPE_ANGLE_YZ: `int` =

Norm type: Divergence.

Value
    12

NORM_TYPE_DIVERGENCE: `int` =

Map of norm types to names.

Value
    13

NORM_TYPE_RADIUS: `int` =

Norm type: Radius X.

Value
    3

NORM_TYPE_RADIUS_X: `int` =

Norm type: Radius Y.

Value
    4

NORM_TYPE_RADIUS_XY: `int` =

Norm type: Radius XZ.

Value
    7

NORM_TYPE_RADIUS_XZ: `int` =

Norm type: Radius YZ.

Value
    8

NORM_TYPE_RADIUS_Y: `int` =

Norm type: Radius Z.

Value
    5

NORM_TYPE_RADIUS_YZ: `int` =

Norm type: Angle XY.

Value
    9

NORM_TYPE_RADIUS_Z: `int` =

Norm type: Radius XY.

Value
    6

NORM_TYPE_X: `int` =

Norm type: Y.

Value
    0

NORM_TYPE_Y: `int` =

Norm type: Z.

Value
    1

NORM_TYPE_Z: `int` =

Norm type: Radius.

Value
    2

Norm_Types_Names_Map =

Default norm type.